@@ -8,6 +8,9 @@ from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
     ACIUpdateDateTupleABC,
 )
 from peek_plugin_graphdb._private.PluginNames import graphDbFilt
+from peek_plugin_graphdb._private.client.controller.ItemKeyIndexCacheController import (
+    clientItemKeyIndexUpdateFromServerFilt,
+)
 from peek_plugin_graphdb._private.tuples.ItemKeyIndexUpdateDateTuple import (
     ItemKeyIndexUpdateDateTuple,
 )
@@ -23,5 +26,6 @@ clientItemKeyIndexWatchUpdateFromDeviceFilt.update(graphDbFilt)
 # ModelSet HANDLER
 class ItemKeyIndexCacheHandler(ACICacheHandlerABC):
     _UpdateDateTuple: ACIUpdateDateTupleABC = ItemKeyIndexUpdateDateTuple
-    _updateFromServerFilt: Dict = clientItemKeyIndexWatchUpdateFromDeviceFilt
+    _updateFromDeviceFilt: Dict = clientItemKeyIndexWatchUpdateFromDeviceFilt
+    _updateFromLogicFilt: Dict = clientItemKeyIndexUpdateFromServerFilt
     _logger: logging.Logger = logger
