@@ -25,7 +25,9 @@ class ItemKeyIndexEncodedChunk(Tuple, DeclarativeBase, ACIEncodedChunkTupleABC):
     id = Column(BigInteger, primary_key=True, autoincrement=True)
 
     modelSetId = Column(
-        Integer, ForeignKey("GraphDbModelSet.id", ondelete="CASCADE"), nullable=False
+        Integer,
+        ForeignKey("GraphDbModelSet.id", ondelete="CASCADE"),
+        nullable=False,
     )
     modelSet = relationship(GraphDbModelSet)
 
@@ -47,6 +49,10 @@ class ItemKeyIndexEncodedChunk(Tuple, DeclarativeBase, ACIEncodedChunkTupleABC):
     def ckiChunkKey(self):
         return self.chunkKey
 
+    @property
+    def ckiEncodedData(self):
+        return self.encodedData
+
     @property
     def ckiLastUpdate(self):
         return self.lastUpdate
@@ -63,6 +69,10 @@ class ItemKeyIndexEncodedChunk(Tuple, DeclarativeBase, ACIEncodedChunkTupleABC):
     def sqlCoreChunkKeyColumn(cls):
         return cls.__table__.c.chunkKey
 
+    @classmethod
+    def sqlCoreLastUpdateColumn(cls):
+        return cls.__table__.c.lastUpdate
+
     @classmethod
     def sqlCoreLoad(cls, row):
         return ItemKeyIndexEncodedChunk(
