@@ -2,23 +2,26 @@ import hashlib
 import json
 from typing import List
 
+import json
 from vortex.Tuple import addTupleType, TupleField, Tuple
 
 from peek_plugin_graphdb._private.PluginNames import graphDbTuplePrefix
 from peek_plugin_graphdb.tuples.GraphDbImportEdgeTuple import GraphDbImportEdgeTuple
-from peek_plugin_graphdb.tuples.GraphDbImportSegmentLinkTuple import \
-    GraphDbImportSegmentLinkTuple
+from peek_plugin_graphdb.tuples.GraphDbImportSegmentLinkTuple import (
+    GraphDbImportSegmentLinkTuple,
+)
 from peek_plugin_graphdb.tuples.GraphDbImportVertexTuple import GraphDbImportVertexTuple
 
 
 @addTupleType
 class GraphDbImportSegmentTuple(Tuple):
-    """ Import Segment Tuple
+    """Import Segment Tuple
 
     This tuple is the publicly exposed Segment
 
     """
-    __tupleType__ = graphDbTuplePrefix + 'GraphDbImportSegmentTuple'
+
+    __tupleType__ = graphDbTuplePrefix + "GraphDbImportSegmentTuple"
 
     #:  The unique key of this segment
     key: str = TupleField()
@@ -39,7 +42,7 @@ class GraphDbImportSegmentTuple(Tuple):
     importGroupHash: str = TupleField()
 
     def sortDataForHashing(self) -> None:
-        """ Generate Segment Key
+        """Generate Segment Key
 
         This method generates a unique has of this segment based on its internal
         contents, that is, the edges, vertexes but not links to other segments.
@@ -56,7 +59,7 @@ class GraphDbImportSegmentTuple(Tuple):
             edge.sortSrcDstForHash()
 
     def generateSegmentKey(self) -> str:
-        """ Generate Segment Key
+        """Generate Segment Key
 
         This method generates a unique has of this segment based on its internal
         contents, that is, the edges, vertexes but not links to other segments.
@@ -65,7 +68,7 @@ class GraphDbImportSegmentTuple(Tuple):
         self.sortDataForHashing()
 
         m = hashlib.md5()
-        m.update(b'zeroth item padding')
+        m.update(b"zeroth item padding")
 
         for edge in self.edges:
             m.update(str(edge).encode())
@@ -76,7 +79,7 @@ class GraphDbImportSegmentTuple(Tuple):
         return m.hexdigest()
 
     def generateSegmentHash(self) -> str:
-        """ Generate Segment Hash
+        """Generate Segment Hash
 
         This method generates a unique has of this segment based on its internal
         and external contents, that is, the edges, vertexes
@@ -86,19 +89,22 @@ class GraphDbImportSegmentTuple(Tuple):
         self.sortDataForHashing()
 
         m = hashlib.md5()
-        m.update(b'zeroth item padding')
+        m.update(b"zeroth item padding")
 
         for edge in self.edges:
-            m.update(json.dumps(edge.tupleToSqlaBulkInsertDict(), sort_keys=True)
-                     .encode())
+            m.update(
+                json.dumps(edge.tupleToSqlaBulkInsertDict(), sort_keys=True).encode()
+            )
 
         for vertex in self.vertexes:
-            m.update(json.dumps(vertex.tupleToSqlaBulkInsertDict(), sort_keys=True)
-                     .encode())
+            m.update(
+                json.dumps(vertex.tupleToSqlaBulkInsertDict(), sort_keys=True).encode()
+            )
 
         for link in self.links:
-            m.update(json.dumps(link.tupleToSqlaBulkInsertDict(), sort_keys=True)
-                     .encode())
+            m.update(
+                json.dumps(link.tupleToSqlaBulkInsertDict(), sort_keys=True).encode()
+            )
 
         m.update(self.key.encode())
         m.update(self.modelSetKey.encode())
@@ -109,6 +115,6 @@ class GraphDbImportSegmentTuple(Tuple):
         jsonDict = dict(
             edges=[i.packJsonDict() for i in self.edges],
             links=[i.packJsonDict() for i in self.links],
-            vertexes=[i.packJsonDict() for i in self.vertexes]
+            vertexes=[i.packJsonDict() for i in self.vertexes],
         )
-        return json.dumps(jsonDict, sort_keys=True, indent='')
+        return json.dumps(jsonDict, sort_keys=True, indent="")
